@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm 2921 2010-05-05 23:58:14Z mbarbon $
-## Copyright:   (c) 2000-2010 Mattia Barbon
+## RCS-ID:      $Id: Wx.pm 3157 2012-02-28 14:55:59Z mdootson $
+## Copyright:   (c) 2000-2011 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $XS_VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.9702';
+$VERSION = '0.9905';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -142,7 +142,7 @@ use strict 'refs';
 
 *Wx::Window::GetClientSizeWH = \&Wx::Window::GetClientSizeXY;
 
-if( Load() ) {
+if( Load( 1 ) ) {
     SetConstants();
     SetConstantsOnce();
     SetOvlConstants();
@@ -165,11 +165,6 @@ eval( "sub wxGTK() { $_platform == $_gtk }" );
 eval( "sub wxMAC() { $_platform == $_mac }" );
 eval( "sub wxX11() { $_platform == $_x11 }" );
 
-# Mac OS X warning
-if( wxMAC() && $^X !~ m{/wxPerl\.app/} && !$ENV{HARNESS_ACTIVE} ) {
-    warn "On Mac OS X please run scripts with the 'wxPerl' interpreter\n";
-}
-
 require Wx::App;
 require Wx::Event;
 require Wx::Locale;
@@ -353,6 +348,36 @@ must be placed in the same directory as the executable file.
       </dependency>
   </assembly>
 
+=head1 Running on Mac OSX
+
+From version 0.98 wxPerl no longer needs to use the special startup
+executable 'wxperl' to run scripts on the Mac. The ordinary perl
+interpreter now works without problems. This is because wxPerl now
+contains code that brings the running application to the front and
+gives it the focus.
+
+In a syntax checking editor you may prevent Wx code from being
+given focus as the front process by setting an environment variable
+
+export WXPERL_OPTIONS=NO_MAC_SETFRONTPROCESS
+
+or 
+
+$ENV{WXPERL_OPTIONS} = 'NO_MAC_SETFRONTPROCESS';
+
+The code that makes the SetFrontProcess call is in Wx::Mini as
+
+Wx::MacSetFrontProcess();
+
+so it is also straightforward to override this method if you wish.
+
+Finally, any code can force the running application to become the
+front process regardless of environment settings by calling the xs
+method directly. (Note the underscore in the method name).
+
+Wx::_MacSetFrontProcess();
+
+
 =head1 AUTHOR
 
 Mattia Barbon <mbarbon@cpan.org>
